@@ -17,8 +17,8 @@ TRAIT_PREFIX_VNIC_TYPE = 'VNIC_TYPE_'
 TRAIT_PREFIX_PHYSNET = 'PHYSNET_'
 
 # resource classes
-CLASS_NET_BW_EGRESS_KBPS = 'NET_BANDWIDTH_EGRESS_KILOBITS_PER_SECOND'
-CLASS_NET_BW_INGRESS_KBPS = 'NET_BANDWIDTH_INGRESS_KILOBITS_PER_SECOND'
+CLASS_NET_BW_EGRESS_KBPS = 'NET_BW_EGR_KILOBIT_PER_SEC'
+CLASS_NET_BW_INGRESS_KBPS = 'NET_BW_IGR_KILOBIT_PER_SEC'
 
 # Optionally reported inventory parameters. Mandatory parameters like 'total'
 # are left out intentionally. See also:
